@@ -1,17 +1,10 @@
 package Bot::Cobalt::Plugin::Silly::AutoOpAll;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
-
-use 5.12.1;
-use strict;
-use warnings;
+$Bot::Cobalt::Plugin::Silly::AutoOpAll::VERSION = '0.030001';
+use strictures 2;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
-use IRC::Utils qw/lc_irc/;
+use IRC::Utils 'lc_irc';
 
 sub new { bless {}, shift }
 
@@ -24,7 +17,7 @@ sub Cobalt_register {
       'public_cmd_aopall',
   );
 
-  $core->log->info("Loaded ($VERSION)");
+  $core->log->info("Loaded");
 
   return PLUGIN_EAT_NONE
 }
