@@ -1,11 +1,7 @@
 package Bot::Cobalt::Plugin::Silly::BoneEasy;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
+$Bot::Cobalt::Plugin::Silly::BoneEasy::VERSION = '0.030001';
+use strictures 2;
 
-use 5.12.1;
 use Bot::Cobalt::Common;
 
 use Bone::Easy;
@@ -19,7 +15,7 @@ sub Cobalt_register {
     'public_cmd_pickup'
   );
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
 
   return PLUGIN_EAT_NONE
 }
