@@ -1,13 +1,8 @@
 package Bot::Cobalt::Plugin::Silly::DailyFail;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
+$Bot::Cobalt::Plugin::Silly::DailyFail::VERSION = '0.030001';
+use strictures 2;
 
-use 5.12.1;
-
-use Acme::Daily::Fail qw/get_headline/;
+use Acme::Daily::Fail 'get_headline';
 
 use Bot::Cobalt::Common;
 
@@ -20,7 +15,7 @@ sub Cobalt_register {
     'public_cmd_headline', 'public_cmd_dailyfail'
   );
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
 
   return PLUGIN_EAT_NONE
 }
