@@ -1,11 +1,6 @@
 package Bot::Cobalt::Plugin::Silly::LOLCAT;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
-
-use 5.12.1;
+$Bot::Cobalt::Plugin::Silly::LOLCAT::VERSION = '0.030001';
+use strictures 2;
 
 use POE::Filter::Stackable;
 use POE::Filter::Line;
@@ -25,7 +20,7 @@ sub Cobalt_register {
   );
 
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
   return PLUGIN_EAT_NONE
 }
 
