@@ -1,11 +1,6 @@
 package Bot::Cobalt::Plugin::Silly::OutputLOLCAT;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
-
-use 5.12.1;
+$Bot::Cobalt::Plugin::Silly::OutputLOLCAT::VERSION = '0.030001';
+use strictures 2;
 
 use POE::Filter::Stackable;
 use POE::Filter::Line;
@@ -24,7 +19,7 @@ sub Cobalt_register {
     'message'
   );
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
   
   PLUGIN_EAT_NONE
 }
