@@ -1,14 +1,8 @@
 package Bot::Cobalt::Plugin::Silly::OutputLeet;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
-
-use 5.12.1;
+$Bot::Cobalt::Plugin::Silly::OutputLeet::VERSION = '0.030001';
+use strictures 2;
 
 use Acme::LeetSpeak;
-
 use Bot::Cobalt::Common;
 
 sub new { bless [], shift }
@@ -20,7 +14,7 @@ sub Cobalt_register {
     'message'
   );
 
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
   
   return PLUGIN_EAT_NONE
 }
