@@ -1,13 +1,6 @@
 package Bot::Cobalt::Plugin::Silly::Reverse;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
-
-use 5.12.1;
-use strict;
-use warnings;
+$Bot::Cobalt::Plugin::Silly::Reverse::VERSION = '0.030001';
+use strictures 2;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
@@ -20,7 +13,7 @@ sub Cobalt_register {
     'public_cmd_reverse'
   );
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
 
   return PLUGIN_EAT_NONE
 }
