@@ -1,13 +1,7 @@
 package Bot::Cobalt::Plugin::Silly::Rot13;
-our $VERSION;
-BEGIN {
-  require Bot::Cobalt::Plugin::Silly;
-  $VERSION = $Bot::Cobalt::Plugin::Silly::VERSION;
-}
+$Bot::Cobalt::Plugin::Silly::Rot13::VERSION = '0.030001';
+use strictures 2;
 
-use 5.12.1;
-use strict;
-use warnings;
 use Object::Pluggable::Constants qw/ :ALL /;
 
 sub new { bless [], shift }
@@ -19,7 +13,7 @@ sub Cobalt_register {
     'public_cmd_rot13'
   );
   
-  $core->log->info("$VERSION loaded");
+  $core->log->info("Loaded");
 
   return PLUGIN_EAT_NONE
 }
